From: tip-bot for Leo Yan <tipbot@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: mathieu.poirier@linaro.org, hpa@zytor.com,
alexander.shishkin@linux.intel.com, mingo@kernel.org,
leo.yan@linaro.org, acme@redhat.com, namhyung@kernel.org,
mike.leach@linaro.org, linux-kernel@vger.kernel.org,
robert.walker@arm.com, jolsa@redhat.com, tglx@linutronix.de
Subject: [tip:perf/core] perf cs-etm: Rename CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY
Date: Thu, 20 Dec 2018 10:14:36 -0800 [thread overview]
Message-ID: <tip-49ccf87bfb9e8517ab2f019e95845760c4c3a562@git.kernel.org> (raw)
In-Reply-To: <1544513908-16805-6-git-send-email-leo.yan@linaro.org>
Commit-ID: 49ccf87bfb9e8517ab2f019e95845760c4c3a562
Gitweb: https://git.kernel.org/tip/49ccf87bfb9e8517ab2f019e95845760c4c3a562
Author: Leo Yan <leo.yan@linaro.org>
AuthorDate: Tue, 11 Dec 2018 15:38:25 +0800
Committer: Arnaldo Carvalho de Melo <acme@redhat.com>
CommitDate: Tue, 18 Dec 2018 12:23:59 -0300
perf cs-etm: Rename CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY
TRACE_ON element is used at the beginning of trace, it also can be
appeared in the middle of trace data to indicate discontinuity; for
example, it's possible to see multiple TRACE_ON elements in the trace
stream if the trace is being limited by address range filtering.
Furthermore, except TRACE_ON element is for discontinuity, NO_SYNC and
EO_TRACE also can be used to indicate discontinuity, though they are
used for different scenarios for which the trace is interrupted.
This patch renames sample type CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY,
firstly the new name describes more closely the purpose of the packet;
secondly this is a preparation for other output elements which also
cause the trace discontinuity thus they can share the same one packet
type.
Signed-off-by: Leo Yan <leo.yan@linaro.org>
Reviewed-by: Mathieu Poirier <mathieu.poirier@linaro.org>
Cc: Alexander Shishkin <alexander.shishkin@linux.intel.com>
Cc: Jiri Olsa <jolsa@redhat.com>
Cc: Mike Leach <mike.leach@linaro.org>
Cc: Namhyung Kim <namhyung@kernel.org>
Cc: Robert Walker <robert.walker@arm.com>
Cc: coresight@lists.linaro.org
Cc: linux-arm-kernel@lists.infradead.org
Link: http://lkml.kernel.org/r/1544513908-16805-6-git-send-email-leo.yan@linaro.org
Signed-off-by: Arnaldo Carvalho de Melo <acme@redhat.com>
---
tools/perf/util/cs-etm-decoder/cs-etm-decoder.c | 10 +++++-----
tools/perf/util/cs-etm-decoder/cs-etm-decoder.h | 2 +-
tools/perf/util/cs-etm.c | 12 ++++++------
3 files changed, 12 insertions(+), 12 deletions(-)
diff --git a/tools/perf/util/cs-etm-decoder/cs-etm-decoder.c b/tools/perf/util/cs-etm-decoder/cs-etm-decoder.c
index 97b39b1f5759..1039f364f4cc 100644
--- a/tools/perf/util/cs-etm-decoder/cs-etm-decoder.c
+++ b/tools/perf/util/cs-etm-decoder/cs-etm-decoder.c
@@ -390,11 +390,11 @@ cs_etm_decoder__buffer_range(struct cs_etm_decoder *decoder,
}
static ocsd_datapath_resp_t
-cs_etm_decoder__buffer_trace_on(struct cs_etm_decoder *decoder,
- const uint8_t trace_chan_id)
+cs_etm_decoder__buffer_discontinuity(struct cs_etm_decoder *decoder,
+ const uint8_t trace_chan_id)
{
return cs_etm_decoder__buffer_packet(decoder, trace_chan_id,
- CS_ETM_TRACE_ON);
+ CS_ETM_DISCONTINUITY);
}
static ocsd_datapath_resp_t cs_etm_decoder__gen_trace_elem_printer(
@@ -412,8 +412,8 @@ static ocsd_datapath_resp_t cs_etm_decoder__gen_trace_elem_printer(
case OCSD_GEN_TRC_ELEM_NO_SYNC:
break;
case OCSD_GEN_TRC_ELEM_TRACE_ON:
- resp = cs_etm_decoder__buffer_trace_on(decoder,
- trace_chan_id);
+ resp = cs_etm_decoder__buffer_discontinuity(decoder,
+ trace_chan_id);
break;
case OCSD_GEN_TRC_ELEM_INSTR_RANGE:
resp = cs_etm_decoder__buffer_range(decoder, elem,
diff --git a/tools/perf/util/cs-etm-decoder/cs-etm-decoder.h b/tools/perf/util/cs-etm-decoder/cs-etm-decoder.h
index 3819a04a2c27..a27231722e27 100644
--- a/tools/perf/util/cs-etm-decoder/cs-etm-decoder.h
+++ b/tools/perf/util/cs-etm-decoder/cs-etm-decoder.h
@@ -25,7 +25,7 @@ struct cs_etm_buffer {
enum cs_etm_sample_type {
CS_ETM_EMPTY,
CS_ETM_RANGE,
- CS_ETM_TRACE_ON,
+ CS_ETM_DISCONTINUITY,
};
enum cs_etm_isa {
diff --git a/tools/perf/util/cs-etm.c b/tools/perf/util/cs-etm.c
index ffc4fe5c0b7e..cea3158915d3 100644
--- a/tools/perf/util/cs-etm.c
+++ b/tools/perf/util/cs-etm.c
@@ -562,8 +562,8 @@ static inline int cs_etm__t32_instr_size(struct cs_etm_queue *etmq,
static inline u64 cs_etm__first_executed_instr(struct cs_etm_packet *packet)
{
- /* Returns 0 for the CS_ETM_TRACE_ON packet */
- if (packet->sample_type == CS_ETM_TRACE_ON)
+ /* Returns 0 for the CS_ETM_DISCONTINUITY packet */
+ if (packet->sample_type == CS_ETM_DISCONTINUITY)
return 0;
return packet->start_addr;
@@ -572,8 +572,8 @@ static inline u64 cs_etm__first_executed_instr(struct cs_etm_packet *packet)
static inline
u64 cs_etm__last_executed_instr(const struct cs_etm_packet *packet)
{
- /* Returns 0 for the CS_ETM_TRACE_ON packet */
- if (packet->sample_type == CS_ETM_TRACE_ON)
+ /* Returns 0 for the CS_ETM_DISCONTINUITY packet */
+ if (packet->sample_type == CS_ETM_DISCONTINUITY)
return 0;
return packet->end_addr - packet->last_instr_size;
@@ -972,7 +972,7 @@ static int cs_etm__sample(struct cs_etm_queue *etmq)
bool generate_sample = false;
/* Generate sample for tracing on packet */
- if (etmq->prev_packet->sample_type == CS_ETM_TRACE_ON)
+ if (etmq->prev_packet->sample_type == CS_ETM_DISCONTINUITY)
generate_sample = true;
/* Generate sample for branch taken packet */
@@ -1148,7 +1148,7 @@ static int cs_etm__run_decoder(struct cs_etm_queue *etmq)
*/
cs_etm__sample(etmq);
break;
- case CS_ETM_TRACE_ON:
+ case CS_ETM_DISCONTINUITY:
/*
* Discontinuity in trace, flush
* previous branch stack
next prev parent reply other threads:[~2018-12-20 18:14 UTC|newest]
Thread overview: 48+ messages / expand[flat|nested] mbox.gz Atom feed top
2018-12-11 7:38 [PATCH v3 0/8] perf cs-etm: Correct packets handling Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-11 7:38 ` [PATCH v3 1/8] perf cs-etm: Correct packets swapping in cs_etm__flush() Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-20 18:12 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 2/8] perf cs-etm: Avoid stale branch samples when flush packet Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-20 18:12 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 3/8] perf cs-etm: Remove unused 'trace_on' in cs_etm_decoder Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-12 18:41 ` Mathieu Poirier
2018-12-12 18:41 ` Mathieu Poirier
2018-12-20 18:13 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 4/8] perf cs-etm: Refactor enumeration cs_etm_sample_type Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-12 18:41 ` Mathieu Poirier
2018-12-12 18:41 ` Mathieu Poirier
2018-12-20 18:14 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 5/8] perf cs-etm: Rename CS_ETM_TRACE_ON to CS_ETM_DISCONTINUITY Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-20 18:14 ` tip-bot for Leo Yan [this message]
2018-12-11 7:38 ` [PATCH v3 6/8] perf cs-etm: Treat NO_SYNC element as trace discontinuity Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-13 12:38 ` Arnaldo Carvalho de Melo
2018-12-13 12:38 ` Arnaldo Carvalho de Melo
2018-12-13 12:41 ` Arnaldo Carvalho de Melo
2018-12-13 12:41 ` Arnaldo Carvalho de Melo
2018-12-13 13:09 ` leo.yan
2018-12-13 13:09 ` leo.yan
2018-12-13 13:21 ` Arnaldo Carvalho de Melo
2018-12-13 13:21 ` Arnaldo Carvalho de Melo
2018-12-13 13:23 ` leo.yan
2018-12-13 13:23 ` leo.yan
2018-12-13 13:26 ` Arnaldo Carvalho de Melo
2018-12-13 13:26 ` Arnaldo Carvalho de Melo
2018-12-13 13:31 ` leo.yan
2018-12-13 13:31 ` leo.yan
2018-12-20 18:15 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 7/8] perf cs-etm: Treat EO_TRACE " Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-20 18:15 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-11 7:38 ` [PATCH v3 8/8] perf cs-etm: Generate branch sample for exception packet Leo Yan
2018-12-11 7:38 ` Leo Yan
2018-12-20 18:16 ` [tip:perf/core] " tip-bot for Leo Yan
2018-12-12 18:45 ` [PATCH v3 0/8] perf cs-etm: Correct packets handling Mathieu Poirier
2018-12-12 18:45 ` Mathieu Poirier
2018-12-13 13:11 ` Arnaldo Carvalho de Melo
2018-12-13 13:11 ` Arnaldo Carvalho de Melo
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-49ccf87bfb9e8517ab2f019e95845760c4c3a562@git.kernel.org \
--to=tipbot@zytor.com \
--cc=acme@redhat.com \
--cc=alexander.shishkin@linux.intel.com \
--cc=hpa@zytor.com \
--cc=jolsa@redhat.com \
--cc=leo.yan@linaro.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mathieu.poirier@linaro.org \
--cc=mike.leach@linaro.org \
--cc=mingo@kernel.org \
--cc=namhyung@kernel.org \
--cc=robert.walker@arm.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.